
/* Chrysalide - Outil d'analyse de fichiers binaires
 * block-int.h - prototypes pour la définition interne des blocs d'instructions
 *
 * Copyright (C) 2012-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _ANALYSIS_BLOCK_INT_H
#define _ANALYSIS_BLOCK_INT_H


#include "block.h"



/* Recherche le bloc contenant une adresse donnée. */
typedef GInstrBlock * (* find_by_addr_fc) (const GInstrBlock *, const vmpa2t *, bool);

/* Parcourt tous les blocs d'instructions dans un ordre donné. */
typedef bool (* visit_all_blocks_fc) (GInstrBlock *, instr_block_visitor_cb, void *);

/* Etablit la liste de tous les blocs présents. */
typedef void (* list_all_blocks_fc) (const GInstrBlock *, GInstrBlock ***, size_t *);

/* Etablit la liste de tous les blocs terminaux. */
typedef void (* list_leafs_blocks_fc) (const GInstrBlock *, GInstrBlock ***, size_t *);


/* Fournit les différents accès aux registres. */
//typedef const reg_access * (* list_regs_accesses_fc) (const GInstrBlock *, size_t *);



/* Description d'un bloc d'instructions (instance) */
struct _GInstrBlock
{
    GObject parent;                         /* A laisser en premier        */

    GInstrBlock *links_block;               /* Lieu des blocs attachés     */

};

/* Description d'un bloc d'instructions (classe) */
struct _GInstrBlockClass
{
    GObjectClass parent;                    /* A laisser en premier        */

    find_by_addr_fc find_by_addr;           /* Recherche par adresse       */
    visit_all_blocks_fc visit_blocks;       /* Visite des différents blocs */
    list_all_blocks_fc list_blocks;         /* Liste de tous les blocs     */
    list_leafs_blocks_fc list_leafs;        /* Liste des blocs terminaux   */
    //list_regs_accesses_fc list_regs;        /* Liste des accès registres   */

};






#endif  /* _ANALYSIS_BLOCK_INT_H */
